@@ -86,6 +86,8 @@ import easybuild.tools.options as eboptions
 import easybuild.tools.parallelbuild as parbuild
 from easybuild.framework.easyblock import EasyBlock, get_class
 from easybuild.framework.easyconfig.easyconfig import EasyConfig, ITERATE_OPTIONS
+from easybuild.framework.easyconfig.format.version import EasyVersion
+from easybuild.framework.easyconfig.format.one import retrieve_blocks_in_spec
 from easybuild.framework.easyconfig.tools import get_paths_for
 from easybuild.tools import systemtools
 from easybuild.tools.config import get_repository, module_classes, get_log_filename, get_repositorypath
@@ -690,81 +692,6 @@ def robot_find_easyconfig(path, name, version):
     return None
 
 
-def retrieve_blocks_in_spec(spec, onlyBlocks, silent=False):
-    """
-    Easyconfigs can contain blocks (headed by a [Title]-line)
-    which contain commands specific to that block. Commands in the beginning of the file
-    above any block headers are common and shared between each block.
-    """
-    regBlock = re.compile(r"^\s*\[([\w.-]+)\]\s*$", re.M)
-    regDepBlock = re.compile(r"^\s*block\s*=(\s*.*?)\s*$", re.M)
-
-    cfgName = os.path.basename(spec)
-    pieces = regBlock.split(open(spec).read())
-
-    # the first block contains common statements
-    common = pieces.pop(0)
-    if pieces:
-        # make a map of blocks
-        blocks = []
-        while pieces:
-            blockName = pieces.pop(0)
-            blockContents = pieces.pop(0)
-
-            if blockName in [b['name'] for b in blocks]:
-                msg = "Found block %s twice in %s." % (blockName, spec)
-                _log.error(msg)
-
-            block = {'name': blockName, 'contents': blockContents}
-
-            # dependency block
-            depBlock = regDepBlock.search(blockContents)
-            if depBlock:
-                dependencies = eval(depBlock.group(1))
-                if type(dependencies) == list:
-                    block['dependencies'] = dependencies
-                else:
-                    block['dependencies'] = [dependencies]
-
-            blocks.append(block)
-
-        # make a new easyconfig for each block
-        # they will be processed in the same order as they are all described in the original file
-        specs = []
-        for block in blocks:
-            name = block['name']
-            if onlyBlocks and not (name in onlyBlocks):
-                print_msg("Skipping block %s-%s" % (cfgName, name), silent=silent)
-                continue
-
-            (fd, blockPath) = tempfile.mkstemp(prefix='easybuild-', suffix='%s-%s' % (cfgName, name))
-            os.close(fd)
-
-            txt = common
-
-            if 'dependencies' in block:
-                for dep in block['dependencies']:
-                    if not dep in [b['name'] for b in blocks]:
-                        log.error("Block %s depends on %s, but block was not found." % (name, dep))
-
-                    dep = [b for b in blocks if b['name'] == dep][0]
-                    txt += "\n# Dependency block %s" % (dep['name'])
-                    txt += dep['contents']
-
-            txt += "\n# Main block %s" % name
-            txt += block['contents']
-
-            write_file(blockPath, txt)
-
-            specs.append(blockPath)
-
-        _log.debug("Found %s block(s) in %s" % (len(specs), spec))
-        return specs
-    else:
-        # no blocks, one file
-        return [spec]
-
-
 def get_build_stats(app, starttime):
     """
     Return build statistics for this build
@@ -777,7 +704,7 @@ def get_build_stats(app, starttime):
                               ('host', os.uname()[1]),
                               ('platform' , platform.platform()),
                               ('cpu_model', systemtools.get_cpu_model()),
-                              ('core_count', systemtools.get_core_count()),
+                              ('core_count', systemtools.get_avail_core_count()),
                               ('timestamp', int(time.time())),
                               ('build_time', buildtime),
                               ('install_size', app.det_installsize()),
