@@ -43,12 +43,12 @@ import tempfile
 from distutils.version import LooseVersion
 from subprocess import PIPE
 from vsc import fancylogger
-from vsc.utils.missing import get_subclasses
+from vsc.utils.missing import get_subclasses, any
 
 from easybuild.tools.build_log import EasyBuildError
-from easybuild.tools.config import get_modules_tool
-from easybuild.tools.filetools import convert_name, run_cmd, read_file
-from easybuild.tools.module_generator import det_full_module_name, DEVEL_MODULE_SUFFIX
+from easybuild.tools.config import get_modules_tool, install_path
+from easybuild.tools.filetools import convert_name, run_cmd, read_file, which
+from easybuild.tools.module_generator import det_full_module_name, DEVEL_MODULE_SUFFIX, GENERAL_CLASS
 from easybuild.tools.toolchain import DUMMY_TOOLCHAIN_NAME, DUMMY_TOOLCHAIN_VERSION
 from vsc.utils.missing import nub
 
@@ -61,7 +61,7 @@ DEVEL_ENV_VAR_NAME_PREFIX = "EBDEVEL"
 # see e.g., https://bugzilla.redhat.com/show_bug.cgi?id=719785
 LD_LIBRARY_PATH = os.getenv('LD_LIBRARY_PATH', '')
 
-outputMatchers = {
+output_matchers = {
     # matches whitespace and module-listing headers
     'whitespace': re.compile(r"^\s*$|^(-+).*(-+)$"),
     # matches errors such as "cmdTrace.c(713):ERROR:104: 'asdfasdf' is an unrecognized subcommand"
@@ -69,10 +69,48 @@ outputMatchers = {
     # ModuleCmd_Avail.c(529):ERROR:57: Error while reading directory '/usr/local/modulefiles/SCIENTIFIC'
     # ModuleCmd_Avail.c(804):ERROR:64: Directory '/usr/local/modulefiles/SCIENTIFIC/tremolo' not found
     'error': re.compile(r"^\S+:(?P<level>\w+):(?P<code>(?!57|64)\d+):\s+(?P<msg>.*)$"),
-    # available with --terse has one module per line
-    # matches modules such as "ictce/3.2.1.015.u4"
-    # lines ending in ':' are ignored (the modulepath(s) in --terse)
-    'available': re.compile(r"^\s*(?P<mod_name>[^\(\s:]+)(?P<default>\(default\))?\s*[^:\S]*$"),
+    # 'available' with --terse has one module per line, with some extra lines (module path(s), module directories...)
+    # regex below matches modules like 'ictce/3.2.1.015.u4', 'OpenMPI/1.6.4-no-OFED', ...
+    #
+    # Module lines notes:
+    # * module name may have '(default)' appeneded [modulecmd]
+    # ignored lines:
+    # * module paths lines may start with a (empty) set of '-'s, which will be followed by a space [modulecmd.tcl]
+    # * module paths may end with a ':' [modulecmd, lmod]
+    # * module directories lines may end with a '/' [lmod >= 5.1.5]
+    #
+    # Note: module paths may be relative paths!
+    #
+    # Example outputs for the different supported module tools, for the same set of modules files (only two, both GCC):
+    #
+    #   $ modulecmd python avail --terse GCC > /dev/null
+    #       /path/tomodules:
+    #       GCC/4.6.3
+    #       GCC/4.6.4(default)
+    #
+    #   $ lmod python avail --terse GCC > /dev/null
+    #       /path/to/modules:
+    #       GCC/
+    #       GCC/4.6.3
+    #       GCC/4.6.4
+    #
+    #   $ modulecmd.tcl python avail -t GCC > /dev/null
+    #       -------- /path/to/modules --------
+    #       GCC/4.6.3
+    #       GCC/4.6.4
+    #
+    # Note on modulecmd.tcl: if the terminal is not wide enough, or the module path too long, the '-'s are not there!
+    #
+    # Any modules with a name that does not match the regex constructed below, will be HIDDEN from EasyBuild
+    #
+    'available': re.compile(r"""
+        ^(?!-*\s)                     # disallow lines starting with (empty) list of '-'s followed by a space
+        (?P<mod_name>                 # start named group for module name
+            [^\s\(]*[^:/]             # module name must not have '(' or whitespace in it, must not end with ':' or '/'
+        )                             # end named group for module name
+        (?P<default>\(default\))?     # optional '(default)' that's not part of module name
+        \s*$                          # ignore whitespace at the end of the line
+        """, re.VERBOSE),
 }
 
 _log = fancylogger.getLogger('modules', fname=False)
@@ -102,9 +140,15 @@ class ModulesTool(object):
         # actual module command (i.e., not the 'module' wrapper function, but the binary)
         self.cmd = None
 
+        # shell that should be used to run module command (specified above) in (if any)
+        self.shell = None
+
         # version of modules tool
         self.version = None
 
+        # terse command line option
+        self.add_terse_opt_fn = lambda x: x.insert(0, '--terse')
+
     @property
     def modules(self):
         """Property providing access to deprecated 'modules' class variable."""
@@ -113,36 +157,49 @@ class ModulesTool(object):
 
     def check_cmd_avail(self):
         """Check whether modules tool command is available."""
-        which_ec = subprocess.call(["which", self.cmd], stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-        if which_ec != 0:
-            self.log.error("%s modules tool can not be used, '%s' command is not available." % (self.__class__.__name__, self.cmd))
+        cmd_path = which(self.cmd)
+        if cmd_path is not None:
+            self.cmd = cmd_path
+            self.log.info("Full path for module command is %s, so using it" % self.cmd)
+        else:
+            mod_tool = self.__class__.__name__
+            self.log.error("%s modules tool can not be used, '%s' command is not available." % (mod_tool, self.cmd))
 
     def check_module_path(self):
         """
         Check if MODULEPATH is set and change it if necessary.
         """
-        if not 'MODULEPATH' in os.environ:
-            errormsg = 'MODULEPATH not found in environment'
-            # check if environment-modules is found
-            module_regexp = re.compile(r"^module is a function\s*\nmodule\s*()")
-            cmd = "type module"
-            (out, ec) = run_cmd(cmd, log_all=False, log_ok=False)
-            if ec != 0 or not module_regexp.match(out):
-                errormsg += "; environment-modules doesn't seem to be installed: "
-                errormsg += "'%s' failed with exit code %s and output: '%s'" % (cmd, ec, out.strip('\n'))
-            self.log.error(errormsg)
-
-        if self.mod_paths:
-            # set the module path environment accordingly
-            os.environ['MODULEPATH'] = ':'.join(self.mod_paths)
-            self.log.debug("$MODULEPATH set based on supplied list of module paths: %s" % os.environ['MODULEPATH'])
-        else:
+        # if self.mod_paths is not specified, use $MODULEPATH and make sure the EasyBuild module path is in there (first)
+        if self.mod_paths is None:
             # take module path from environment
-            self.mod_paths = nub(os.environ['MODULEPATH'].split(':'))
+            self.mod_paths = [x for x in nub(os.environ.get('MODULEPATH', '').split(':')) if len(x) > 0]
             self.log.debug("self.mod_paths set based on $MODULEPATH: %s" % self.mod_paths)
 
-        if not 'LOADEDMODULES' in os.environ:
-            os.environ['LOADEDMODULES'] = ''
+            # determine module path for EasyBuild install path to be included in $MODULEPATH
+            eb_modpath = os.path.join(install_path(typ='modules'), GENERAL_CLASS)
+
+            # make sure EasyBuild module path is in 1st place
+            self.mod_paths = [x for x in self.mod_paths if not x == eb_modpath]
+            self.mod_paths.insert(0, eb_modpath)
+            self.log.info("Prepended list of module paths with path used by EasyBuild: %s" % eb_modpath)
+
+        # set the module path environment accordingly
+        os.environ['MODULEPATH'] = ':'.join(self.mod_paths)
+        self.log.info("$MODULEPATH set based on list of module paths: %s" % os.environ['MODULEPATH'])
+
+    def use_module_paths(self):
+        """Run 'module use' on all paths in $MODULEPATH."""
+        # we need to run '<module command> python use <path>' on all paths in $MODULEPATH
+        # not all modules tools follow whatever is in $MODULEPATH, some take extra action for every module path
+        # usually, additional environment variables are set, e.g. $LMOD_DEFAULT_MODULEPATH or $MODULEPATH_modshare
+        # note: we're stepping through the mod_paths in reverse order to preserve order in $MODULEPATH in the end
+        for modpath in self.mod_paths[::-1]:
+            if not os.path.isabs(modpath):
+                modpath = os.path.join(os.getcwd(), modpath)
+            if os.path.exists(modpath):
+                self.run_module(['use', modpath])
+            else:
+                self.log.warning("Ignoring non-existing module path in $MODULEPATH: %s" % modpath)
 
     def available(self, mod_name=None):
         """
@@ -276,6 +333,10 @@ class ModulesTool(object):
         """Get the software name for a given module name."""
         raise NotImplementedError
 
+    def set_ld_library_path(self, ld_library_paths):
+        """Set $LD_LIBRARY_PATH to the given list of paths."""
+        os.environ['LD_LIBRARY_PATH'] = ':'.join(ld_library_paths)
+
     def run_module(self, *args, **kwargs):
         """
         Run module command.
@@ -286,41 +347,61 @@ class ModulesTool(object):
             args = list(args)
 
         if args[0] in ('available', 'avail', 'list',):
-            args.insert(0, '--terse')  # run these in terse mode for better machinereading
+            self.add_terse_opt_fn(args)  # run these in terse mode for easier machine reading
 
-        originalModulePath = os.environ['MODULEPATH']
-        if kwargs.get('mod_paths', None):
-            os.environ['MODULEPATH'] = kwargs.get('mod_paths')
-        elif kwargs.get('modulePath', None):
-            os.environ['MODULEPATH'] = kwargs.get('modulePath')
-            self.log.deprecated("Use of 'modulePath' named argument in 'run_module', should use 'mod_paths'.", "2.0")
+        module_path_key = None
+        original_module_path = None
+        if 'mod_paths' in kwargs:
+            module_path_key =  'mod_paths'
+        elif 'modulePath' in kwargs:
+            module_path_key =  'modulePath'
+        if module_path_key is not None:
+            original_module_path = os.environ['MODULEPATH']
+            os.environ['MODULEPATH'] = kwargs[module_path_key]
+            self.log.deprecated("Use of '%s' named argument in 'run_module'" % module_path_key, '2.0')
+
+        # after changing $MODULEPATH, we should adjust self.mod_paths and run use_module_paths(),
+        # but we can't do that here becaue it would yield infinite recursion on run_module
         self.log.debug('Current MODULEPATH: %s' % os.environ['MODULEPATH'])
-        self.log.debug("Running '%s python %s' from %s..." % (self.cmd, ' '.join(args), os.getcwd()))
+
         # change our LD_LIBRARY_PATH here
         environ = os.environ.copy()
         environ['LD_LIBRARY_PATH'] = LD_LIBRARY_PATH
-        self.log.debug("Adjusted LD_LIBRARY_PATH from '%s' to '%s'" %
-                       (os.environ.get('LD_LIBRARY_PATH', ''), environ['LD_LIBRARY_PATH']))
+        cur_ld_library_path = os.environ.get('LD_LIBRARY_PATH', '')
+        new_ld_library_path = environ['LD_LIBRARY_PATH']
+        self.log.debug("Adjusted LD_LIBRARY_PATH from '%s' to '%s'" % (cur_ld_library_path, new_ld_library_path))
 
-        # module command is now getting an outdated LD_LIBRARY_PATH, which will be adjusted on loading a module
-        # this needs to be taken into account when updating the environment via produced output, see below
-        self.log.debug("Running module cmd '%s python %s'" % (self.cmd, ' '.join(args)))
-        proc = subprocess.Popen([self.cmd, 'python'] + args, stdout=PIPE, stderr=PIPE, env=environ)
+        # prefix if a particular shell is specified, using shell argument to Popen doesn't work (no output produced (?))
+        cmdlist = [self.cmd, 'python']
+        if self.shell is not None:
+            cmdlist.insert(0, self.shell)
+
+        self.log.debug("Running module command '%s' from %s" % (' '.join(cmdlist + args), os.getcwd()))
+        proc = subprocess.Popen(cmdlist + args, stdout=PIPE, stderr=PIPE, env=environ)
         # stdout will contain python code (to change environment etc)
         # stderr will contain text (just like the normal module command)
         (stdout, stderr) = proc.communicate()
-        os.environ['MODULEPATH'] = originalModulePath
+        if original_module_path is not None:
+            os.environ['MODULEPATH'] = original_module_path
+            self.log.deprecated("Restoring $MODULEPATH back to what it was before running module command/.", '2.0')
+            # after changing $MODULEPATH, we should adjust self.mod_paths and run use_module_paths(),
+            # but we can't do that here becaue it would yield infinite recursion on run_module
 
         if kwargs.get('return_output', False):
             return stdout + stderr
         else:
+            # the module command was run with an outdated LD_LIBRARY_PATH, which will be adjusted on loading a module
+            # this needs to be taken into account when updating the environment via produced output, see below
+
             # keep track of current LD_LIBRARY_PATH, so we can correct the adjusted LD_LIBRARY_PATH below
             prev_ld_library_path = os.environ.get('LD_LIBRARY_PATH', '').split(':')[::-1]
 
             # Change the environment
             try:
-                clean_stdout = '\n'.join([line for line in stdout.split('\n') if line.startswith('os.environ[')])
-                exec clean_stdout
+                tweak_fn = kwargs.get('tweak_stdout')
+                if tweak_fn is not None:
+                    stdout = tweak_fn(stdout)
+                exec stdout
             except Exception, err:
                 out = "stdout: %s, stderr: %s" % (stdout, stderr)
                 raise EasyBuildError("Changing environment as dictated by module failed: %s (%s)" % (err, out))
@@ -332,27 +413,33 @@ class ModulesTool(object):
 
             self.log.debug("Correcting paths in LD_LIBRARY_PATH from %s to %s" %
                            (curr_ld_library_path, new_ld_library_path))
-            os.environ['LD_LIBRARY_PATH'] = ':'.join(new_ld_library_path)
+            self.set_ld_library_path(new_ld_library_path)
 
             # Process stderr
             result = []
             for line in stderr.split('\n'):  # IGNORE:E1103
-                if outputMatchers['whitespace'].search(line):
+                if output_matchers['whitespace'].search(line):
                     continue
 
-                error = outputMatchers['error'].search(line)
+                error = output_matchers['error'].search(line)
                 if error:
                     self.log.error(line)
                     raise EasyBuildError(line)
 
-                modules = outputMatchers['available'].finditer(line)
+                modules = output_matchers['available'].finditer(line)
                 for module in modules:
                     result.append(module.groupdict())
             return result
 
     def loaded_modules(self):
         """Return a list of loaded modules."""
-        raise NotImplementedError
+        # obtain list of loaded modules from 'module list' using --terse
+        mods = [mod['mod_name'] for mod in self.run_module('list')]
+
+        # filter out devel modules
+        loaded_modules = [mod for mod in mods if not mod.endswith(DEVEL_MODULE_SUFFIX)]
+
+        return loaded_modules
 
     # depth=sys.maxint should be equivalent to infinite recursion depth
     def dependencies_for(self, mod_name, depth=sys.maxint):
@@ -396,36 +483,82 @@ class EnvironmentModulesC(ModulesTool):
         self.cmd = "modulecmd"
         self.check_cmd_avail()
 
+        # run 'modulecmd python use <path>' for all paths in $MODULEPATH
+        self.use_module_paths()
+
     def module_software_name(self, mod_name):
         """Get the software name for a given module name."""
         # line that specified conflict contains software name
-        name_re = re.compile('^conflict\s*(?P<name>[^ ]+).*$', re.M)
+        name_re = re.compile('^conflict\s*(?P<name>\S+).*$', re.M)
         return self.get_value_from_modulefile(mod_name, name_re)
 
-    def loaded_modules(self):
-        """Return a list of loaded modules."""
-
-        loaded_modules = []
-        mods = []
-
-        # 'modulecmd python list' doesn't yield anything useful, prints to stdout
-        # rely on $LOADEDMODULES
-        if os.getenv('LOADEDMODULES'):
-            # format: name1/version1:name2/version2:...:nameN/versionN
-            mods = os.getenv('LOADEDMODULES').split(':')
-        else:
-            self.log.debug("No way found to determine loaded modules, assuming no modules are loaded.")
-
-        # filter devel modules, since they cannot be split like this
-        loaded_modules = [mod for mod in mods if not mod.endswith(DEVEL_MODULE_SUFFIX)]
-
-        return loaded_modules
-
     def update(self):
         """Update after new modules were added."""
         pass
 
 
+class EnvironmentModulesTcl(EnvironmentModulesC):
+    """Interface to (Tcl) environment modules (modulecmd.tcl)."""
+
+    def __init__(self, *args, **kwargs):
+        """Constructor, set modulecmd.tcl-specific class variable values."""
+        super(EnvironmentModulesC, self).__init__(*args, **kwargs)
+        self.cmd = 'modulecmd.tcl'
+        # older versions of modulecmd.tcl don't have a decent hashbang, so we run it under a tclsh shell
+        self.shell = 'tclsh'
+        self.check_cmd_avail()
+
+        # Tcl environment modules have no --terse (yet), -t must be added after the command ('avail', 'list', etc.)
+        self.add_terse_opt_fn = lambda x: x.insert(1, '-t')
+
+        # run 'modulecmd.tcl python use <path>' for all paths in $MODULEPATH
+        self.use_module_paths()
+
+    def set_ld_library_path(self, ld_library_paths):
+        """Set $LD_LIBRARY_PATH to the given list of paths."""
+        super(EnvironmentModulesTcl, self).set_ld_library_path(ld_library_paths)
+        # for Tcl environment modules, we need to make sure the _modshare env var is kept in sync
+        os.environ['LD_LIBRARY_PATH_modshare'] = ':1:'.join(ld_library_paths)
+
+    def run_module(self, *args, **kwargs):
+        """
+        Run module command, tweak output that is exec'ed if necessary.
+        """
+        if isinstance(args[0], (list, tuple,)):
+            args = args[0]
+
+        # old versions of modulecmd.tcl spit out something like "exec '<file>'" for load commands,
+        # which is not correct Python code (and it knows, as the comments in modulecmd.tcl indicate)
+        # so, rewrite "exec '/tmp/modulescript_X'" to the correct "execfile('/tmp/modulescript_X')"
+        # this is required for the DEISA variant of modulecmd.tcl which is commonly used
+        def tweak_stdout(txt):
+            """Tweak stdout before it's exec'ed as Python code."""
+            modulescript_regex = "^exec\s+[\"'](?P<modulescript>/tmp/modulescript_[0-9_]+)[\"']$"
+            return re.sub(modulescript_regex, r"execfile('\1')", txt)
+
+        tweak_stdout_fn = None
+        # for 'active' module (sub)commands that yield changes in environment, we need to tweak stdout before exec'ing
+        if args[0] in ['load', 'purge', 'unload', 'use']:
+            tweak_stdout_fn = tweak_stdout
+        kwargs.update({'tweak_stdout': tweak_stdout_fn})
+
+        return super(EnvironmentModulesTcl, self).run_module(*args, **kwargs)
+
+    def available(self, mod_name=None):
+        """
+        Return a list of available modules for the given (partial) module name;
+        use None to obtain a list of all available modules.
+
+        @param name: a (partial) module name for filtering (default: None)
+        """
+        mods = super(EnvironmentModulesTcl, self).available(mod_name=mod_name)
+        # strip off slash at beginning, if it's there
+        # under certain circumstances, 'modulecmd.tcl avail' (DEISA variant) spits out available modules like this
+        clean_mods = [mod.lstrip(os.path.sep) for mod in mods]
+
+        return clean_mods
+
+
 class Lmod(ModulesTool):
     """Interface to Lmod."""
 
@@ -454,7 +587,7 @@ class Lmod(ModulesTool):
             stdout = open(stdout_fn, 'w')
             stderr = open(stdout_fn, 'w')
             # version is printed in 'lmod help' output
-            subprocess.call(["lmod", "help"], stdout=stdout, stderr=stderr)
+            subprocess.call([self.cmd, "help"], stdout=stdout, stderr=stderr)
             stdout.close()
             stderr.close()
 
@@ -466,7 +599,7 @@ class Lmod(ModulesTool):
                 self.version = LooseVersion(res.group('version'))
                 self.log.info("Found Lmod version %s" % self.version)
             else:
-                self.log.error("Failed to determine Lmod version from 'lmod help' output: %s" % txt)
+                self.log.error("Failed to determine Lmod version from '%s help' output: %s" % (self.cmd, txt))
             stderr.close()
         except (IOError, OSError), err:
             self.log.error("Failed to check Lmod version: %s" % err)
@@ -480,16 +613,8 @@ class Lmod(ModulesTool):
             vers = (self.REQ_VERSION, self.OPT_VERSION, self.version)
             self.log.error("EasyBuild requires Lmod version >= %s (>= %s recommended), found v%s" % vers)
 
-        # we need to run 'lmod python use <path>' to make sure all paths in $MODULEPATH are taken into account
-        # note: we're stepping through the mod_paths in reverse order to preserve order in $MODULEPATH in the end
-        for modpath in self.mod_paths[::-1]:
-            if not os.path.isabs(modpath):
-                modpath = os.path.join(os.getcwd(), modpath)
-            full_cmd = [self.cmd, 'python', 'use', modpath]
-            self.log.debug("Running %s" % ' '.join(full_cmd))
-            proc = subprocess.Popen(full_cmd, stdout=PIPE, stderr=PIPE, env=os.environ)
-            (stdout, stderr) = proc.communicate()
-            exec stdout
+        # run 'lmod python use <path>' for all paths in $MODULEPATH
+        self.use_module_paths()
 
         # make sure lmod spider cache is up to date
         self.update()
@@ -528,12 +653,6 @@ class Lmod(ModulesTool):
 
         return correct_real_mods
 
-    def loaded_modules(self):
-        """Return a list of loaded modules."""
-        # run_module already returns a list of Python dictionaries for loaded modules
-        # only retain 'mod_name' keys, get rid of any other keys
-        return [mod['mod_name'] for mod in self.run_module('list')]
-
     def update(self):
         """Update after new modules were added."""
         cmd = ['spider', '-o', 'moduleT', os.environ['MODULEPATH']]
@@ -545,7 +664,7 @@ class Lmod(ModulesTool):
 
         try:
             cache_filefn = os.path.join(os.path.expanduser('~'), '.lmod.d', '.cache', 'moduleT.lua')
-            self.log.debug("Updating lmod spider cache %s with output from '%s'" % (cache_filefn, ' '.join(cmd)))
+            self.log.debug("Updating Lmod spider cache %s with output from '%s'" % (cache_filefn, ' '.join(cmd)))
             cache_dir = os.path.dirname(cache_filefn)
             if not os.path.exists(cache_dir):
                 os.makedirs(cache_dir)
@@ -592,6 +711,39 @@ def get_software_root(name, with_env_var=False):
         return root
 
 
+def get_software_libdir(name, only_one=True, fs=None):
+    """
+    Find library subdirectories for the specified software package.
+
+    Returns the library subdirectory, relative to software root.
+    It fails if multiple library subdirs are found, unless only_one is False which yields a list of all library subdirs.
+
+    @param: name of the software package
+    @param only_one: indicates whether only one lib path is expected to be found
+    @param fs: only retain library subdirs that contain one of the files in this list
+    """
+    lib_subdirs = ['lib', 'lib64']
+    root = get_software_root(name)
+    res = []
+    if root:
+        for lib_subdir in lib_subdirs:
+            if os.path.exists(os.path.join(root, lib_subdir)):
+                if fs is None or any([os.path.exists(os.path.join(root, lib_subdir, f)) for f in fs]):
+                    res.append(lib_subdir)
+        # if no library subdir was found, return None
+        if not res:
+            return None
+        if only_one:
+            if len(res) == 1:
+                res = res[0]
+            else:
+                _log.error("Multiple library subdirectories found for %s in %s: %s" % (name, root, ', '.join(res)))
+        return res
+    else:
+        # return None if software package root could not be determined
+        return None
+
+
 def get_software_version_env_var_name(name):
     """Return name of environment variable for software root."""
     newname = convert_name(name, upper=True)
@@ -619,7 +771,7 @@ def curr_module_paths():
     """
     Return a list of current module paths.
     """
-    return os.environ['MODULEPATH'].split(':')
+    return os.environ.get('MODULEPATH', '').split(':')
 
 
 def mk_module_path(paths):
@@ -642,7 +794,7 @@ def avail_modules_tools():
 
 def modules_tool(mod_paths=None):
     """
-    Return interface to modules tool (environment modules, lmod)
+    Return interface to modules tool (environment modules (C, Tcl), or Lmod)
     """
     # get_modules_tool might return none (e.g. if config was not initialized yet)
     modules_tool = get_modules_tool()
