@@ -31,21 +31,30 @@ Interface module to TORQUE (PBS).
 """
 
 import os
+import tempfile
 import time
 from vsc import fancylogger
 
+
 _log = fancylogger.getLogger('pbs_job', fname=False)
 
+
+MAX_WALLTIME = 72
+# extend paramater should be 'NULL' in some functions because this is required by the python api
+NULL = 'NULL'
+# list of known hold types
+KNOWN_HOLD_TYPES = []
+
 pbs_import_failed = None
 try:
     from PBSQuery import PBSQuery
     import pbs
+    KNOWN_HOLD_TYPES = [pbs.USER_HOLD, pbs.OTHER_HOLD, pbs.SYSTEM_HOLD]
 except ImportError:
     _log.debug("Failed to import pbs from pbs_python. Silently ignoring, is only a real issue with --job")
     pbs_import_failed = ("PBSQuery or pbs modules not available. "
                          "Please make sure pbs_python is installed and usable.")
 
-MAX_WALLTIME = 72
 
 def connect_to_server(pbs_server=None):
     """Connect to PBS server and return connection."""
@@ -57,6 +66,7 @@ def connect_to_server(pbs_server=None):
         pbs_server = pbs.pbs_default()
     return pbs.pbs_connect(pbs_server)
 
+
 def disconnect_from_server(conn):
     """Disconnect a given connection."""
     if pbs_import_failed:
@@ -65,6 +75,7 @@ def disconnect_from_server(conn):
 
     pbs.pbs_disconnect(conn)
 
+
 def get_ppn():
     """Guess the ppn for full node"""
 
@@ -84,6 +95,7 @@ def get_ppn():
 
     return freq_np
 
+
 class PbsJob(object):
     """Interaction with TORQUE"""
 
@@ -143,8 +155,12 @@ class PbsJob(object):
             self.queue = 'long'
         else:
             self.queue = 'short'
+        # job id of this job
         self.jobid = None
+        # list of dependencies for this job
         self.deps = []
+        # list of holds that are placed on this job
+        self.holds = []
 
     def add_dependencies(self, job_ids):
         """
@@ -157,23 +173,21 @@ class PbsJob(object):
 
         self.deps.extend(job_ids)
 
-    def submit(self):
+    def submit(self, with_hold=False):
         """Submit the jobscript txt, set self.jobid"""
         txt = self.script
         self.log.debug("Going to submit script %s" % txt)
 
-
         # Build default pbs_attributes list
         pbs_attributes = pbs.new_attropl(1)
-        pbs_attributes[0].name = 'Job_Name'
+        pbs_attributes[0].name = pbs.ATTR_N  # Job_Name
         pbs_attributes[0].value = self.name
 
-
         # set resource requirements
         resourse_attributes = pbs.new_attropl(len(self.resources))
         idx = 0
         for k, v in self.resources.items():
-            resourse_attributes[idx].name = 'Resource_List'
+            resourse_attributes[idx].name = pbs.ATTR_l  # Resource_List
             resourse_attributes[idx].resource = k
             resourse_attributes[idx].value = v
             idx += 1
@@ -187,6 +201,15 @@ class PbsJob(object):
             pbs_attributes.extend(deps_attributes)
             self.log.debug("Job deps attributes: %s" % deps_attributes[0].value)
 
+        # submit job with (user) hold if requested
+        if with_hold:
+            hold_attributes = pbs.new_attropl(1)
+            hold_attributes[0].name = pbs.ATTR_h
+            hold_attributes[0].value = pbs.USER_HOLD
+            pbs_attributes.extend(hold_attributes)
+            self.holds.append(pbs.USER_HOLD)
+            self.log.debug("Job hold attributes: %s" % hold_attributes[0].value)
+
         # add a bunch of variables (added by qsub)
         # also set PBS_O_WORKDIR to os.getcwd()
         os.environ.setdefault('WORKDIR', os.getcwd())
@@ -196,7 +219,7 @@ class PbsJob(object):
         # extend PBS variables with specified variables
         pbsvars.extend(["%s=%s" % (name, value) for (name, value) in self.env_vars.items()])
         variable_attributes = pbs.new_attropl(1)
-        variable_attributes[0].name = 'Variable_List'
+        variable_attributes[0].name = pbs.ATTR_v  # Variable_List
         variable_attributes[0].value = ",".join(pbsvars)
 
         pbs_attributes.extend(variable_attributes)
@@ -204,12 +227,11 @@ class PbsJob(object):
 
         # mail settings
         mail_attributes = pbs.new_attropl(1)
-        mail_attributes[0].name = 'Mail_Points'
+        mail_attributes[0].name = pbs.ATTR_m  # Mail_Points
         mail_attributes[0].value = 'n'  # disable all mail
         pbs_attributes.extend(mail_attributes)
         self.log.debug("Job mail attributes: %s" % mail_attributes[0].value)
 
-        import tempfile
         fh, scriptfn = tempfile.mkstemp()
         f = os.fdopen(fh, 'w')
         self.log.debug("Writing temporary job script to %s" % scriptfn)
@@ -218,11 +240,9 @@ class PbsJob(object):
 
         self.log.debug("Going to submit to queue %s" % self.queue)
 
-        # extend paramater should be 'NULL' because this is required by the python api
-        extend = 'NULL'
         # job submission sometimes fails without producing an error, e.g. when one of the dependency jobs has already finished
         # when that occurs, None will be returned by pbs_submit as job id
-        jobid = pbs.pbs_submit(self.pbsconn, pbs_attributes, scriptfn, self.queue, extend)
+        jobid = pbs.pbs_submit(self.pbsconn, pbs_attributes, scriptfn, self.queue, NULL)
         is_error, errormsg = pbs.error()
         if is_error or jobid is None:
             self.log.error("Failed to submit job script %s (job id: %s, error %s)" % (scriptfn, jobid, errormsg))
@@ -231,6 +251,53 @@ class PbsJob(object):
             self.jobid = jobid
             os.remove(scriptfn)
 
+    def set_hold(self, hold_type=None):
+        """Set hold on job of specified type."""
+        # we can't set this default for hold_type in function signature,
+        # because we need to be able to load this module even when the pbs module is not available
+        if hold_type is None:
+            hold_type = pbs.USER_HOLD
+        # only set hold if it wasn't set before
+        if hold_type not in self.holds:
+            if hold_type not in KNOWN_HOLD_TYPES:
+                self.log.error("set_hold: unknown hold type: %s (supported: %s)" % (hold_type, KNOWN_HOLD_TYPES))
+            # set hold, check for errors, and keep track of this hold
+            ec = pbs.pbs_holdjob(self.pbsconn, self.jobid, hold_type, NULL)
+            is_error, errormsg = pbs.error()
+            if is_error or ec:
+                tup = (hold_type, self.jobid, is_error, ec, errormsg)
+                self.log.error("Failed to set hold of type %s on job %s (is_error: %s, exit code: %s, msg: %s)" % tup)
+            else:
+                self.holds.append(hold_type)
+        else:
+            self.log.warning("Hold type %s was already set for %s" % (hold_type, self.jobid))
+
+    def release_hold(self, hold_type=None):
+        """Release hold on job of specified type."""
+        # we can't set this default for hold_type in function signature,
+        # because we need to be able to load this module even when the pbs module is not available
+        if hold_type is None:
+            hold_type = pbs.USER_HOLD
+        # only release hold if it was set
+        if hold_type in self.holds:
+            if hold_type not in KNOWN_HOLD_TYPES:
+                self.log.error("release_hold: unknown hold type: %s (supported: %s)" % (hold_type, KNOWN_HOLD_TYPES))
+            # release hold, check for errors, remove from list of holds
+            ec = pbs.pbs_rlsjob(self.pbsconn, self.jobid, hold_type, NULL)
+            self.log.debug("Released hold of type %s for job %s" % (hold_type, self.jobid))
+            is_error, errormsg = pbs.error()
+            if is_error or ec:
+                tup = (hold_type, self.jobid, is_error, ec, errormsg)
+                self.log.error("Failed to release hold type %s on job %s (is_error: %s, exit code: %s, msg: %s)" % tup)
+            else:
+                self.holds.remove(hold_type)
+        else:
+            self.log.warning("No hold type %s was set for %s, so skipping hold release" % (hold_type, self.jobid))
+
+    def has_holds(self):
+        """Return whether this job has holds or not."""
+        return bool(self.holds)
+
     def state(self):
         """
         Return the state of the job
@@ -287,7 +354,7 @@ class PbsJob(object):
 
         # create attribute list to query pbs with
         if types is None:
-            jobattr = 'NULL'
+            jobattr = NULL
         else:
             jobattr = pbs.new_attrl(len(types))
             for idx, attr in enumerate(types):
@@ -298,7 +365,7 @@ class PbsJob(object):
         if self.clean_conn:
             pbs.pbs_disconnect(self.pbsconn)
             self.pbsconn = pbs.pbs_connect(self.pbs_server)
-        jobs = pbs.pbs_statjob(self.pbsconn, self.jobid, jobattr, 'NULL')
+        jobs = pbs.pbs_statjob(self.pbsconn, self.jobid, jobattr, NULL)
         if len(jobs) == 0:
             # no job found, return None info
             res = None
