@@ -32,6 +32,11 @@ import os
 import platform
 import re
 from vsc import fancylogger
+try:
+    # this import fails with Python 2.4 because it requires the ctypes module (only in Python 2.5+)
+    from vsc.utils.affinity import sched_getaffinity
+except ImportError:
+    pass
 
 from easybuild.tools.filetools import read_file, run_cmd
 
@@ -53,50 +58,79 @@ class SystemToolsException(Exception):
     """raised when systemtools fails"""
 
 
-def get_core_count():
-    """Try to detect the number of virtual or physical CPUs on this system.
-
-    inspired by http://stackoverflow.com/questions/1006289/how-to-find-out-the-number-of-cpus-in-python/1006301#1006301
+def get_avail_core_count():
     """
-    # Python 2.6+
-    try:
-        from multiprocessing import cpu_count
-        return cpu_count()
-    except (ImportError, NotImplementedError):
-        pass
-
-    # POSIX
-    try:
-        cores = int(os.sysconf('SC_NPROCESSORS_ONLN'))
-        if cores > 0:
-            return cores
-    except (AttributeError, ValueError):
-        pass
+    Returns the number of available CPUs, according to cgroups and taskssets limits
+    """
+    # tiny inner function to help figure out number of available cores in a cpuset
+    def count_bits(n):
+        """Count the number of set bits for a given integer."""
+        bit_cnt = 0
+        while n > 0:
+            n &= n - 1
+            bit_cnt += 1
+        return bit_cnt
 
     os_type = get_os_type()
-
     if os_type == LINUX:
+        try:
+            # the preferred approach is via sched_getaffinity (yields a long, so cast it down to int)
+            num_cores = int(sum(sched_getaffinity().cpus))
+            return num_cores
+        except NameError:
+            pass
+
+        # in case sched_getaffinity isn't available, fall back to relying on /proc/cpuinfo
+
+        # determine total number of cores via /proc/cpuinfo
         try:
             txt = read_file('/proc/cpuinfo', log_error=False)
             # sometimes this is uppercase
-            res = txt.lower().count('processor\t:')
-            if res > 0:
-                return res
+            max_num_cores = txt.lower().count('processor\t:')
         except IOError, err:
-            raise SystemToolsException("An error occured while determining core count: %s" % err)
+            raise SystemToolsException("An error occured while determining total core count: %s" % err)
+
+        # determine cpuset we're in (if any)
+        mypid = os.getpid()
+        try:
+            f = open("/proc/%s/status" % mypid, 'r')
+            txt = f.read()
+            f.close()
+            cpuset = re.search("^Cpus_allowed:\s*([0-9,a-f]+)", txt, re.M|re.I)
+        except IOError:
+            cpuset = None
+
+        if cpuset is not None:
+            # use cpuset mask to determine actual number of available cores
+            mask_as_int = long(cpuset.group(1).replace(',', ''), 16)
+            num_cores_in_cpuset = count_bits((2**max_num_cores - 1) & mask_as_int)
+            _log.info("In cpuset with %s CPUs" % num_cores_in_cpuset)
+            return num_cores_in_cpuset
+        else:
+            _log.debug("No list of allowed CPUs found, not in a cpuset.")
+            return max_num_cores
     else:
         # BSD
         try:
             out, _ = run_cmd('sysctl -n hw.ncpu')
-            cores = int(out)
-            if cores > 0:
-                return cores
+            num_cores = int(out)
+            if num_cores > 0:
+                return num_cores
         except ValueError:
             pass
 
     raise SystemToolsException('Can not determine number of cores on this system')
 
 
+def get_core_count():
+    """
+    Try to detect the number of virtual or physical CPUs on this system
+    (DEPRECATED, use get_avail_core_count instead)
+    """
+    _log.deprecated("get_core_count() is deprecated, use get_avail_core_count() instead", '2.0')
+    return get_avail_core_count()
+
+
 def get_cpu_vendor():
     """Try to detect the cpu identifier
 
