@@ -1,7 +1,5 @@
-##
-# Copyright 2012 Ghent University
-# Copyright 2012 Stijn De Weirdt
-# Copyright 2012 Kenneth Hoste
+# #
+# Copyright 2012-2013 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -23,17 +21,20 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
-##
+# #
 """
 Module that contains a set of classes and function to generate variables to be used
-eg in compiling or linking
-"""
+e.g., in compiling or linking
 
-from vsc.fancylogger import getLogger
+@author: Stijn De Weirdt (Ghent University)
+@author: Kenneth Hoste (Ghent University)
+"""
+from vsc import fancylogger
 import copy
 import os
 
-_log = getLogger()
+_log = fancylogger.getLogger('variables', fname=False)
+
 
 def get_class(name, default_class, map_class=None):
     """Return class based on default
@@ -56,6 +57,7 @@ def get_class(name, default_class, map_class=None):
 
     return klass
 
+
 def join_map_class(map_classes):
     """Join all class_maps into single class_map"""
     res = {}
@@ -64,11 +66,11 @@ def join_map_class(map_classes):
             if isinstance(k, (str,)):
                 var_name = k
                 if isinstance(v, (tuple, list)):
-                    ## second element is documentation
+                    # second element is documentation
                     klass = v[0]
                 res[var_name] = klass
             elif type(k) in (type,):
-                ## k is the class, v a list of tuples (name,doc)
+                # k is the class, v a list of tuples (name,doc)
                 klass = k
                 default = res.setdefault(klass, [])
                 default.extend([tpl[0] for tpl in v])
@@ -77,6 +79,7 @@ def join_map_class(map_classes):
 
     return res
 
+
 class StrList(list):
     """List of strings"""
     SEPARATOR = ' '
@@ -87,14 +90,14 @@ class StrList(list):
     BEGIN = None
     END = None
 
-    POSITION = 0 # when sorting in list of list: < 0 -> left; > 0 : right
-    SANITIZE_REMOVE_DUPLICATE_KEEP = None  ## used with ListOfList
+    POSITION = 0  # when sorting in list of list: < 0 -> left; > 0 : right
+    SANITIZE_REMOVE_DUPLICATE_KEEP = None  # used with ListOfList
 
     JOIN_BEGIN_END = False
 
-    def __init__(self, *args , **kwargs):
+    def __init__(self, *args, **kwargs):
         super(StrList, self).__init__(*args, **kwargs)
-        self.log = getLogger(self.__class__.__name__)
+        self.log = fancylogger.getLogger(self.__class__.__name__, fname=False)
 
     def str_convert(self, x):
         """Convert members of list to string (no prefix of begin and end)"""
@@ -129,153 +132,26 @@ class StrList(list):
 
     def copy(self):
         """Return copy of self"""
+        return copy.deepcopy(self)
 
-        # keep track of originals
-        log = self.log
-        begin = self.BEGIN
-        end = self.END
+    def try_remove(self, values):
+        """Remove without ValueError in case of missing element"""
+        for value in values:
+            try:
+                self.remove(value)
+            except ValueError:
+                pass
 
-        # clear stuff that will/may cause problems whe deepcopying
-        # e.g. loggers can't be deepcopied (and begin/end are again (derived) instances of StrList)
-        self.log = None
-        self.BEGIN = None
-        self.END = None
-
-        # perform the actual copy
-        res = copy.deepcopy(self)
-
-        # reinstate a (new) logger
-        res.log = getLogger(self.__class__.__name__)
-
-        # also copy begin/end
-        try:
-            res.BEGIN = begin.copy()
-        except:
-            res.BEGIN = copy.deepcopy(begin)
-        try:
-            res.END = end.copy()
-        except:
-            res.END = copy.deepcopy(end)
-
-        # restore originals
-        self.log = log
-        self.BEGIN = begin
-        self.END = end
-
-        # return copy result
-        return res
 
 class CommaList(StrList):
     """Comma-separated list"""
     SEPARATOR = ','
 
 
-## TODO (KH) These are toolchain specific classes/functions already, so move to toolchain.variables?
-## FlagList, CommandFlagList, LibraryList, LinkerFlagList
-class FlagList(StrList):
-    """Flag list"""
-    PREFIX = "-"
-
-class CommandFlagList(FlagList):
-    """
-    Command and flags list
-        First of the list has no prefix (i.e. the executable)
-        The remainder of the options are considered flags
-    """
-    def _str_self(self):
-        """Like a regular flag list, but set first element to original value"""
-        tmp_str = [self.str_convert(x) for x in self if self._str_ok(x)]
-        if len(tmp_str) > 0:
-            tmp_str[0] = self[0]
-        return tmp_str
-
-class LibraryList(StrList):
-    """Link library list"""
-    PREFIX = "-l"
-
-    SANITIZE_REMOVE_DUPLICATE_KEEP = -1  ##  sanitize from end
-
-    JOIN_BEGIN_END = True
-
-    def set_packed_linker_options(self):
-        """Use packed linker options format"""
-        if isinstance(self.BEGIN, LinkerFlagList) and isinstance(self.BEGIN, LinkerFlagList):
-            self.log.debug("sanitize: PACKED_LINKER_OPTIONS")
-            self.BEGIN.PACKED_LINKER_OPTIONS = True
-            self.END.PACKED_LINKER_OPTIONS = True
-
-            self.SEPARATOR = ','
-
-class CommaStaticLibs(LibraryList):
-    """Comma-separated list"""
-    SEPARATOR = ','
-
-    PREFIX = 'lib'
-    SUFFIX = '.a'
-
-class LinkerFlagList(StrList):
-    """Linker flags"""
-
-    PREFIX = '-Wl,'
-
-    LINKER_TOGGLE_START_STOP_GROUP = None
-    LINKER_TOGGLE_STATIC_DYNAMIC = None
-
-    PACKED_LINKER_OPTIONS = None
-
-    IS_BEGIN = None
-    IS_END = None
-
-    def _toggle_map(self, toggle_map, name, descr, idx=None):
-        """Append value from toggle_map. Raise if not None and name not found
-            descr string to add to raise
-        """
-        if toggle_map is not None:
-            if name in toggle_map:
-                if idx is None:
-                    self.append(toggle_map[name])
-                else:
-                    self.insert(idx, toggle_map[name])
-            else:
-                self.log.raiseException("%s name %s not found in map %s" % (descr, name, toggle_map))
-
-    def toggle_startgroup(self):
-        """Append start group"""
-        self._toggle_map(self.LINKER_TOGGLE_START_STOP_GROUP, 'start', 'toggle_startgroup', idx=None)
-
-    def toggle_stopgroup(self):
-        """Append stop group"""
-        self._toggle_map(self.LINKER_TOGGLE_START_STOP_GROUP, 'stop', 'toggle_stopgroup', idx=0)
-
-    def toggle_static(self):
-        """Append static linking flags"""
-        self._toggle_map(self.LINKER_TOGGLE_STATIC_DYNAMIC, 'static', 'toggle_static', idx=0)
-
-    def toggle_dynamic(self):
-        """Append dynamic linking flags"""
-        self._toggle_map(self.LINKER_TOGGLE_STATIC_DYNAMIC, 'dynamic', 'toggle_dynamic', idx=None)
-
-    def sanitize(self):
-        ## TODO: rewrite to avoid changing constants
-        if self.PACKED_LINKER_OPTIONS:
-            ## somehow this should only be run once.
-            self.PACKED_LINKER_OPTIONS = None
-
-            self.log.debug("sanitize: PACKED_LINKER_OPTIONS")
-            self.SEPARATOR = ','
-            if self.IS_BEGIN:
-                self.BEGIN = str(self.PREFIX).rstrip(self.SEPARATOR)
-            self.PREFIX = None
-            self.log.debug("sanitize: PACKED_LINKER_OPTIONS IS_BEGIN %s PREFIX %s BEGIN %s" % (self.IS_BEGIN, self.PREFIX, self.BEGIN))
-
-
-        super(LinkerFlagList, self).sanitize()
-
-
 class AbsPathList(StrList):
     """Absolute paths (eg -L or -I)"""
 
-    SANITIZE_REMOVE_DUPLICATE_KEEP = -1  ##  sanitize from end
+    SANITIZE_REMOVE_DUPLICATE_KEEP = -1  #  sanitize from end
 
     def append_exists(self, prefix, paths, suffix=None, filename=None, append_all=False):
         """
@@ -320,24 +196,15 @@ class AbsPathList(StrList):
             else:
                 self.log.warning("flags_for_subdirs: directory %s was not found" % directory)
 
-## TODO (KH) These are toolchain specific classes/functions already, so move to toolchain.variables?
-## IncludePaths, LinkLibraryPaths, get_linker*
-class IncludePaths(AbsPathList):
-    """Absolute path to directory containing include files"""
-    PREFIX = '-I'
-
-class LinkLibraryPaths(AbsPathList):
-    """Absolute path to directory containing libraries"""
-    PREFIX = '-L'
 
 class ListOfLists(list):
     """List of lists"""
     DEFAULT_CLASS = StrList
     PROTECTED_CLASSES = []  # classes that are not converted to DEFAULT_CLASS
-    #PROTECTED_INSTANCES = [AbsPathList, LibraryList]
+    # PROTECTED_INSTANCES = [AbsPathList, LibraryList]
     PROTECTED_INSTANCES = []
-    PROTECT_CLASS_SELF = True ## don't convert values that are same class as DEFAULT_CLASS
-    PROTECT_INSTANCE_SELF = True ## don't convert values that are instance of DEFAULT_CLASS
+    PROTECT_CLASS_SELF = True  # don't convert values that are same class as DEFAULT_CLASS
+    PROTECT_INSTANCE_SELF = True  # don't convert values that are instance of DEFAULT_CLASS
 
     SEPARATOR = None
 
@@ -345,14 +212,13 @@ class ListOfLists(list):
     SANITIZE_REMOVE_DUPLICATE = False
     SANITIZE_REMOVE_DUPLICATE_KEEP = None
 
-    JOIN_BEGIN_END = False #
+    JOIN_BEGIN_END = False
 
-    def __init__(self, *args , **kwargs):
+    def __init__(self, *args, **kwargs):
         super(ListOfLists, self).__init__(*args, **kwargs)
-        self.log = getLogger(self.__class__.__name__)
+        self.log = fancylogger.getLogger(self.__class__.__name__, fname=False)
         self._first = None
 
-
         self.protected_classes = self.PROTECTED_CLASSES[:]
         if self.PROTECT_CLASS_SELF:
             if not self.DEFAULT_CLASS in self.protected_classes:
@@ -410,12 +276,12 @@ class ListOfLists(list):
             newvalue = value.copy()
         else:
             if isinstance(value, (str, int,)):
-                ## convert to list. although the try/except will work
-                ##  list('XYZ') creates ['X','Y','Z']
+                # convert to list. although the try/except will work
+                #  list('XYZ') creates ['X','Y','Z']
                 value = [value]
 
             try:
-                ## this might work, but probably not
+                # this might work, but probably not
                 newvalue = klass(value, **kwargs)
             except:
                 newvalue = klass(**kwargs)
@@ -437,7 +303,7 @@ class ListOfLists(list):
         klass = kwargs.pop('var_class', self.DEFAULT_CLASS)
         res = []
         if value is None:
-            ## TODO ? append_empty ?
+            # TODO ? append_empty ?
             self.log.raiseException("extend_el with None value unimplemented")
         else:
             for el in value:
@@ -449,12 +315,12 @@ class ListOfLists(list):
                     newvalue = el
                 else:
                     if isinstance(el, (str, int,)):
-                        ## convert to list. although the try/except will work
-                        ##  list('XYZ') creates ['X','Y','Z']
+                        # convert to list. although the try/except will work
+                        #  list('XYZ') creates ['X','Y','Z']
                         el = [el]
 
                     try:
-                        ## this might work, but probably not
+                        # this might work, but probably not
                         newvalue = klass(el)
                     except:
                         newvalue = klass()
@@ -484,16 +350,16 @@ class ListOfLists(list):
             self.sort(key=lambda x: getattr(x, 'POSITION'))
 
         if self.SANITIZE_REMOVE_DUPLICATE:
-            ## get all occurences with their index
+            # get all occurences with their index
             to_remove = []
             for el in self:
                 all_idx = [idx for idx, x in enumerate(self) if x == el]
                 if len(all_idx) > 1:
                     if self.SANITIZE_REMOVE_DUPLICATE_KEEP == 0:
-                        ## keep first
+                        # keep first
                         to_remove.extend(all_idx[1:])
                     elif self.SANITIZE_REMOVE_DUPLICATE_KEEP == -1:
-                        ## keep last
+                        # keep last
                         to_remove.extend(all_idx[:-1])
 
             to_remove = sorted(list(set(to_remove)), reverse=True)
@@ -502,20 +368,19 @@ class ListOfLists(list):
                 del self[idx]
 
         if self.JOIN_BEGIN_END:
-            ## group elements with same begin/end into one element
+            # group elements with same begin/end into one element
             to_remove = []
-            for idx in range(1, len(self))[::-1]: # work in reversed order;don't check last one (ie real el 0), it has no next element
+            for idx in range(1, len(self))[::-1]:  # work in reversed order;don't check last one (ie real el 0), it has no next element
                 if self[idx].BEGIN is None or self[idx].END is None: continue
                 self.log.debug("idx %s len %s" % (idx, len(self)))
                 if self[idx].BEGIN == self[idx - 1].BEGIN and self[idx].END == self[idx - 1].END:  # do check POSITION, sorting already done
                     self.log.debug("sanitize: JOIN_BEGIN_END idx %s joining %s and %s" % (idx, self[idx], self[idx - 1]))
                     self[idx - 1].extend(self[idx])
-                    to_remove.append(idx) ## remove current el
+                    to_remove.append(idx)  # remove current el
             to_remove = sorted(list(set(to_remove)), reverse=True)
             for idx in to_remove:
                 del self[idx]
 
-
     def flatten(self):
         res = []
         for x in self:
@@ -526,10 +391,10 @@ class ListOfLists(list):
     def __str__(self):
         self._first = self.get_first()
         self.sanitize()
-        sep = ''  ## default no separator
+        sep = ''  # default no separator
 
         if self._first is None:
-            ## return empty string
+            # return empty string
             self.log.debug("__str__: first is None (self %s)" % self.__repr__())
             return ''
         else:
@@ -539,6 +404,26 @@ class ListOfLists(list):
             self.log.debug("__str__: return %s (self: %s)" % (txt, self.__repr__()))
             return txt
 
+    def try_function_on_element(self, function_name, names=None, args=None, kwargs=None):
+        """Try to run function function_name on each element"""
+        if args is None:
+            args = []
+        if kwargs is None:
+            kwargs = {}
+        for el in self:
+            if hasattr(el, function_name):
+                function = getattr(el, function_name)
+                function(*args, **kwargs)
+
+    def try_remove(self, values):
+        """Try to remove one or more values from the elements"""
+        self.try_function_on_element('try_remove', args=[values])
+
+    def copy(self):
+        """Return copy of self"""
+        return copy.deepcopy(self)
+
+
 class Variables(dict):
     """
     Class to hold variable-like key/value pairs
@@ -558,7 +443,7 @@ class Variables(dict):
 
     def __init__(self, *args, **kwargs):
         super(Variables, self).__init__(*args, **kwargs)
-        self.log = getLogger(self.__class__.__name__)
+        self.log = fancylogger.getLogger(self.__class__.__name__, fname=False)
 
     def get_list_class(self, name):
         """Return the class associated with the name according to the DEFAULT_LISTCLASS and MAP_LISTCLASS"""
@@ -583,7 +468,8 @@ class Variables(dict):
 
             JOIN_BEGIN_END = element_class.JOIN_BEGIN_END
 
-        klass.__name__ = "%s_%s" % (self.__class__.__name__, name)  ## better log messages (most use self.__class__.__name__; would give klass otherwise)
+        # better log messages (most use self.__class__.__name__; would give klass otherwise)
+        klass.__name__ = "%s_%s" % (self.__class__.__name__, name)
         return klass()
 
     def join(self, name, *others):
@@ -611,7 +497,7 @@ class Variables(dict):
         self.nappend(name, value)
 
     def setdefault(self, name, default=None, append_empty=False):
-        #"""append_empty to non-existing element"""
+        # """append_empty to non-existing element"""
         if name in self:
             default = self[name]
         else:
@@ -625,21 +511,19 @@ class Variables(dict):
                 default.append_empty()
         return default
 
-    def try_function_el(self, function_name, names=None):
+    def try_function_on_element(self, function_name, names=None, args=None, kwargs=None):
         """Try to run function function_name on each element of names"""
         if names is None:
             names = self.keys()
         for name in names:
             self.log.debug("try_function_el: name %s function_name %s" % (name, function_name))
-            for el in self[name]:
-                if hasattr(el, function_name):
-                    function = getattr(el, function_name)
-                    function()
+            self[name].try_function_on_element(function_name, args=args, kwargs=kwargs)
 
     def __getattribute__(self, attr_name):
         # allow for pass-through
         if attr_name in ['nappend', 'nextend', 'append_empty', 'first', 'get_class']:
             self.log.debug("Passthrough to LISTCLASS function %s" % attr_name)
+
             def _passthrough(name, *args, **kwargs):
                 """functions that pass through to LISTCLASS instances"""
                 current = self.setdefault(name)
@@ -649,12 +533,13 @@ class Variables(dict):
             return _passthrough
         elif attr_name in ['nappend_el', 'nextend_el', 'append_exists', 'append_subdirs']:
             self.log.debug("Passthrough to LISTCLASS element function %s" % attr_name)
+
             def _passthrough(name, *args, **kwargs):
                 """"Functions that pass through to elements of LISTCLASS (accept idx as index)"""
                 idx = kwargs.pop('idx', -1)
                 if attr_name in ['append_exists', 'append_subdirs']:
                     current = self.setdefault(name)
-                    current.append_empty()  ## always add empty
+                    current.append_empty()  # always add empty
                 else:
                     current = self.setdefault(name, append_empty=True)
                 actual_function = getattr(current[idx], attr_name)
