@@ -36,6 +36,7 @@ import shutil
 import tempfile
 import sys
 
+import easybuild.tools.options as eboptions
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.framework.extension import Extension
 from easybuild.tools import config
@@ -46,6 +47,10 @@ from easybuild.tools.filetools import write_file
 class EasyBlockTest(TestCase):
     """ Baseclass for easyblock testcases """
 
+    # initialize configuration so modules_tool() function works
+    eb_go = eboptions.parse_options()
+    config.init(eb_go.options, eb_go.get_options_by_section('config'))
+
     def writeEC(self):
         """ create temporary easyconfig file """
         write_file(self.eb_file, self.contents)
@@ -54,10 +59,10 @@ class EasyBlockTest(TestCase):
         """ setup """
         fd, self.eb_file = tempfile.mkstemp(prefix='easyblock_test_file_', suffix='.eb')
         os.close(fd)
-        config.variables['log_dir'] = tempfile.mkdtemp()
-        config.variables['install_path'] = tempfile.mkdtemp()
-        config.variables['build_path'] = tempfile.mkdtemp()
-        config.variables['log_format'] = ("temp","temp")
+        config.variables['tmp_logdir'] = tempfile.mkdtemp()
+        config.variables['installpath'] = tempfile.mkdtemp()
+        config.variables['buildpath'] = tempfile.mkdtemp()
+        config.variables['logfile_format'] = ("temp","temp")
         self.cwd = os.getcwd()
 
     def test_empty(self):
@@ -100,7 +105,7 @@ toolchain = {"name":"dummy", "version": "dummy"}
 """
         self.writeEC()
         eb = EasyBlock(self.eb_file)
-        eb.installdir = config.variables['install_path']
+        eb.installdir = config.variables['installpath']
         fake_mod_data = eb.load_fake_module()
         eb.clean_up_fake_module(fake_mod_data)
 
@@ -122,7 +127,7 @@ exts_list = ['ext1']
         """Testcase for extensions"""
         # test for proper error message without the exts_defaultclass set
         eb = EasyBlock(self.eb_file)
-        eb.installdir = config.variables['install_path']
+        eb.installdir = config.variables['installpath']
         self.assertRaises(EasyBuildError, eb.extensions_step)
         self.assertErrorRegex(EasyBuildError, "No default extension class set", eb.extensions_step)
 
@@ -130,8 +135,8 @@ exts_list = ['ext1']
         self.contents += "\nexts_defaultclass = ['easybuild.framework.extension', 'Extension']"
         self.writeEC()
         eb = EasyBlock(self.eb_file)
-        eb.builddir = config.variables['build_path']
-        eb.installdir = config.variables['install_path']
+        eb.builddir = config.variables['buildpath']
+        eb.installdir = config.variables['installpath']
         eb.extensions_step()
 
         # test for proper error message when skip is set, but no exts_filter is set
@@ -158,8 +163,8 @@ exts_defaultclass = ['easybuild.framework.extension', 'Extension']
         self.writeEC()
         eb = EasyBlock(self.eb_file)
         #self.assertTrue('ext1' in eb.exts.keys() and 'ext2' in eb.exts.keys())
-        eb.builddir = config.variables['build_path']
-        eb.installdir = config.variables['install_path']
+        eb.builddir = config.variables['buildpath']
+        eb.installdir = config.variables['installpath']
         eb.skip = True
         eb.extensions_step()
         # 'ext1' should be in eb.exts
@@ -171,12 +176,59 @@ exts_defaultclass = ['easybuild.framework.extension', 'Extension']
         eb.close_log()
         os.remove(eb.logfile)
 
+    def test_make_module_step(self):
+        """Test the make_module_step"""
+        name = "pi"
+        version = "3.14"
+        modextravars = {'PI': '3.1415', 'FOO': 'bar'}
+        modextrapaths = {'PATH': 'pibin', 'CPATH': 'pi/include'}
+        self.contents = '\n'.join([
+            'name = "%s"' % name,
+            'version = "%s"' % version,
+            'homepage = "http://google.com"',
+            'description = "test easyconfig"',
+            "toolchain = {'name': 'dummy', 'version': 'dummy'}",
+            "dependencies = [('foo', '1.2.3')]",
+            "builddependencies = [('bar', '9.8.7')]",
+            "modextravars = %s" % str(modextravars),
+            "modextrapaths = %s" % str(modextrapaths),
+        ])
+
+        # overwrite installpath config setting
+        orig_installpath = config.variables['installpath']
+        installpath = tempfile.mkdtemp()
+        config.variables['installpath'] = installpath
+
+        # test if module is generated correctly
+        self.writeEC()
+        eb = EasyBlock(self.eb_file)
+        eb.installdir = os.path.join(config.variables['installpath'], config.variables['subdir_software'], 'pi', '3.14')
+        modpath = os.path.join(eb.make_module_step(), name, version)
+        self.assertTrue(os.path.exists(modpath))
+
+        # verify contents of module
+        f = open(modpath, 'r')
+        txt = f.read()
+        f.close()
+        self.assertTrue(re.search("^#%Module", txt.split('\n')[0]))
+        self.assertTrue(re.search("^conflict\s+%s$" % name, txt, re.M))
+        self.assertTrue(re.search("^set\s+root\s+%s$" % eb.installdir, txt, re.M))
+        self.assertTrue(re.search('^setenv\s+EBROOT%s\s+".root"\s*$' % name.upper(), txt, re.M))
+        self.assertTrue(re.search('^setenv\s+EBVERSION%s\s+"%s"$' % (name.upper(), version), txt, re.M))
+        for (key, val) in modextravars.items():
+            self.assertTrue(re.search('^setenv\s+%s\s+"%s"$' % (key, val), txt, re.M))
+        for (key, val) in modextrapaths.items():
+            self.assertTrue(re.search('^prepend-path\s+%s\s+\$root/%s$' % (key, val), txt, re.M))
+
+        # restore original settings
+        config.variables['installpath'] = orig_installpath
+
     def tearDown(self):
         """ make sure to remove the temporary file """
         os.remove(self.eb_file)
-        shutil.rmtree(config.variables['log_dir'])
-        shutil.rmtree(config.variables['install_path'])
-        shutil.rmtree(config.variables['build_path'])
+        shutil.rmtree(config.variables['tmp_logdir'])
+        shutil.rmtree(config.variables['installpath'])
+        shutil.rmtree(config.variables['buildpath'])
         os.chdir(self.cwd)
 
     def assertErrorRegex(self, error, regex, call, *args):
